@@ -8,7 +8,7 @@ use 5.014;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '4.11';
+our $VERSION = '4.12';
 
 Travel::Status::DE::HAFAS::Stop->mk_ro_accessors(
 	qw(eva name lat lon distance_m weight));
@@ -22,8 +22,8 @@ sub new {
 	my $ref = {
 		eva        => $loc->{extId} + 0,
 		name       => $loc->{name},
-		lat        => $loc->{crd}{x} * 1e-6,
-		lon        => $loc->{crd}{y} * 1e-6,
+		lat        => $loc->{crd}{y} * 1e-6,
+		lon        => $loc->{crd}{x} * 1e-6,
 		weight     => $loc->{wt},
 		distance_m => $loc->{dist},
 	};
@@ -76,7 +76,7 @@ Travel::Status::DE::HAFAS::Stop - Information about a HAFAS stop.
 
 =head1 VERSION
 
-version 4.11
+version 4.12
 
 =head1 DESCRIPTION
 
